//
// DiskFile.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_DiskFile_h
#define vos_DiskFile_h

#include "vos.h"

#include "File.h"

namespace vos
{
	/**************************************************************************

	>	class DiskFile : public File

		Author:		Tim Browse
		Date:		23/08/99
		Purpose:	Concrete File class for dealing with disk-based files.

	**************************************************************************/

	class DiskFile : public File
	{
		public:
			/// Constructor
			DiskFile();
			/// Destructor
			~DiskFile();

			/// Creating files
			Error Create(const FileSpec &FS);

			/// Combined Create & Open operation
			Error Open(const FileSpec &FS, FileMode Mode = fam_Full);

			//@{
			// Opening and closing files
			virtual Error Open(FileMode Mode = fam_Full);
			virtual void Close();
			//@}

			/// Test to see if a file object is open
			virtual bool IsOpen() const;

			// Determine the size of the file, in bytes
//			virtual Error GetSize(uint* pSize);

			//@{
			/// Binary read/write
			// NB. does no endian conversions
			Error Read(void* pData, uint cBytes, uint* pcBytes = NULL);
			Error Write(const void* pData, uint cBytes, uint* pcBytes = NULL);
			//@}

			//@{
			// Seeking
			Error SeekFromStart(uint Offset);
			Error SeekFromEnd(uint Offset);
			Error SeekRelative(int Offset);
			//@}

			/// Get file read/write pointer position
			Error GetPos(uint* pPos) const;

			/// Test for end of file.
			bool eof() const;

			/// Read a line of text from the file
			Error ReadLine(String* pData);

		protected:
			// Helper function for reporting errors.
			Error RegisterError(int Code, const char *pszFormatString, ...) const;

		private:
			/// Full Spec for the file on disk
			FileSpec	m_FileSpec;		

			/// NULL, or the (open) file handle
			FILE		*m_hFile;		
	};
};

#endif // !vos_DiskFile_h
