//
// DiskLogFile.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "DiskLogFile.h"
#include "DiskFile.h"

namespace vos
{
	/**************************************************************************

	>	DiskLogFile::DiskLogFile(const FileSpec& FSDiskLogFile,
								 LogMode Mode = LogMode_Normal)

		Author:		Tim Browse
		Date:		13/6/00
		Inputs:		FSDiskLogFile - filespec of the file to log to.
					Mode - whether to append to the log file, or erase
						   the contents before starting the log.

		Purpose:	Create a disk based log file.  The disk file contents
					will be deleted when the file is opened for logging
					(unless LogMode_Append is passed in for the 'Mode'
					parameter).

	**************************************************************************/

	DiskLogFile::DiskLogFile(const FileSpec& FSDiskLogFile,
							 LogMode TheLogMode)
	{
		// Create the disk file
		DiskFile* pDiskFile = new DiskFile;

		// Set default mode to write to a text format file
		FileMode TheFileMode = fam_Write | fam_Text;

		// Append log data, if caller requests it
		if (TheLogMode = LogMode_Append)
			TheFileMode |= fam_Append;

		// Try to open the file
		if (pDiskFile->Open(FSDiskLogFile, TheFileMode))
		{
			// It worked - install the log file
			m_pLogFile = pDiskFile;
		}
		else
		{
			// Failed - destroy the disk file object
			delete pDiskFile;
		}
	}

	/**************************************************************************

	>	DiskLogFile::~DiskLogFile()

		Author:		Tim Browse
		Date:		13/6/00

		Purpose:	Destructor - closes and cleans up log file.

	**************************************************************************/

	DiskLogFile::~DiskLogFile()
	{
		if (m_pLogFile != NULL)
		{
			m_pLogFile->Close();
			delete m_pLogFile;
		}
	}
};
