//
// FileLock.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_FileLock_h
#define vos_FileLock_h

#include "StdHdr.h"

#include "vos.h"

#include "FileSpec.h"
#include "ErrorManager.h"

namespace vos
{
	/**************************************************************************

		class FileLock

		Author:		Tim Browse

		Date:		10/09/2000

		Purpose:	Implement file-locking semantics.

					This class implements atomic 'test and set' file
					locking.

					Calls to Lock/Unlock can be nested.

	**************************************************************************/

	class FileLock
	{
		public:
			FileLock();

			// Set up the lock filename
			void SetLockFile(const FileSpec& LockFile);

			// Lock the file - the filename is the name of the lock file
			// itself, *not* the name of the file being contended for.
			Error Lock();

			// Unlock the file
			void Unlock();

			// Is the file currently locked by this object?
			bool IsLocked();

			// Is the file currently locked by another object?
			bool IsLockedByOther();

		private:
			// Name of the lock file being used
			FileSpec m_LockFile;

			// Lock semaphore
			int m_Lock;

			//
			// Platform specific data for file locking...
			//

#if defined VOS_MSWINDOWS

			// Win32 file handle of the lock file.
			HANDLE m_hFile;

#elif defined VOS_MACOS

			// FileSpec of the lock file.
			FSSpec m_FileSpec;

#endif

	};

};


#endif // !vos_FileLock_h
