//
// FilePath.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//


#ifndef vos_FilePath_h
#define vos_FilePath_h

#include "vos.h"

#include "FileSpec.h"
#include "ErrorManager.h"

namespace vos
{
	/////////////////////////////////////////////////////////////////////////
	// FileSpecList
	// Internal helper class for storing a list of folder names

	class FileSpecList
	{
		public:
			FileSpecList(const FileSpec &FileSpec);
			~FileSpecList();

			void Append(const FileSpec &File);
				// Add a file spec to the end of this list

			const FileSpec &GetFileSpec(void) const		{ return(m_FileSpec);	};
				// Get the FileSpec that this link references

			FileSpecList *GetNext(void) const			{ return(m_pNext);		};
				// Get the next FileSpec header in this list

			private:
				FileSpecList *m_pNext;			// Next FileSpecList item
				FileSpec	 m_FileSpec;		// The FileSpec
	};



	/////////////////////////////////////////////////////////////////////////
	// FilePath

	/**************************************************************************
	
	>	class FilePath
	
		Author:		Jason Williams
		Date:		6/9/99
	
		Purpose:	A FilePath object is a simple list of FileSpecs, each of 
					which refers to one folder. The caller can ask a FilePath 
					to locate a file with a given leaf-name, and it will 
					search the folders until it finds a matching file. A full 
					FileSpec is then returned for the file.

					For example:

					\code

						FilePath SearchPath;
						SearchPath.AppendFolder("C:\\Windows");
						SearchPath.AppendFolder("C:\\Windows\\System32");

						FileSpec TheFile;
						if (SearchPath.FindFile("MyFile.txt", &TheFile))
						{
							DiskFile MyFile;

							if (MyFile.Open(TheFile))
							{
								...
							}
						}

					\endcode
	
	**************************************************************************/
	
	class FilePath
	{
		public:
			FilePath() : m_pPaths(NULL)		{};
			/* virtual */ ~FilePath()		{ delete(m_pPaths); m_pPaths = NULL; };

			FilePath(const FilePath &Source);
			FilePath &operator=(const FilePath &Source);

		public:
			void AppendFolder(const String &FolderName);
			void AppendFolder(const FileSpec &Folder);

			Error FindFile(const FileSpec &fsFilename, /* to */ FileSpec *pFileSpec) const;

		public:
			// Retrieve the linked list of FileSpecs in this path
			FileSpecList *GetFileSpecList(void) const	{ return(m_pPaths);	};

		private:
			FileSpecList *m_pPaths;
	};
};


#endif // !vos_FilePath_h
