//
// Folders.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_Folders_h
#define vos_Folders_h

#include "vos.h"

#include "FileSpec.h"
#include "ErrorManager.h"
#include "ErrorCodes.h"

namespace vos
{
	
	/**************************************************************************

		class Folders

		Author:		Rob Myers

		Date:		8/10/01

		Purpose:	Locate special folders such as the user's Home or Document
					directory, the application's preferences or temp directory,
					or the desktop.
					These folders *MUST* be on writable media.

	**************************************************************************/

	class Folders
	{
		public:
		
			// These are assumed to be user specific
			// If not, fall back to a global location
			
			// The user's 'home' directory
			static Error UserHome(FileSpec * pTarget);
			
			// The user's 'documents' dircectory, probably in their 'home'
			// If no such directory exists, fall back to their 'home'
			static Error UserDocuments(FileSpec * pTarget);
			
			// The user's 'preferences' dircectory, probably in their 'home'
			// If no such directory exists, fall back to their 'home',
			// do *NOT* use a global preferences directory
			static Error UserPreferences(FileSpec * pTarget);

			// The Application's home directory (i.e. where the EXE/image is)
			static Error ApplicationHome(FileSpec * pTarget);
			
			// These are assumed to be global
			// If not, try pretty hard to make them so
			
			// This is not guaranteed to be deleted at the end of the session
			// But should be
			static Error SystemTemp(FileSpec * pTarget);
			
			// The install location for new applications
			static Error SystemApplications(FileSpec * pTarget);

			
			// Function to change where the app thinks it is being run from.
			// (Useful only very rarely)
			static void SetAppFolder(const FileSpec& AppFolder){m_AppFolderOverride = AppFolder;}

		private:
			static FileSpec m_AppFolderOverride;
	};

};


#endif // !vos_Folders_h
