//
// Log.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Log.h"

#include <limits.h>

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vos
{
	/**************************************************************************
	
	>	Log::Log()
	
		Author:		Tim Browse
		Date:		15/4/2002
	
		Purpose:	Constructor
	
	**************************************************************************/
	
	Log::Log() : m_Severity(UINT_MAX)
	{
	}

	/**************************************************************************
	
	>	Log::~Log()
	
		Author:		Tim Browse
		Date:		15/4/2002
	
		Purpose:	Virtual Destructor
					
	
	**************************************************************************/
	
	Log::~Log()
	{
	}

	/**************************************************************************
	
	>	void Log::LogMsg(const String& Msg, uint Severity, uint32 Flags)
	
		Author:		Tim Browse
		Date:		15/4/2002
		Inputs:		Msg - the message to log
					Severity - the severity of the message (0 is most
							   severe).  You can ignore severity if you 
							   want, and can just use 0 all the time.
					Flags - any flags associated with the message.  The
							base Log interface places no meaning on these
							flags - but derived classes may use them.
	
		Purpose:	Write a message to the Log object.
	
	**************************************************************************/
	
	void Log::LogMsg(const String& Msg, uint Severity, uint32 Flags)
	{
		LogMsg(Msg.c_str(), Severity, Flags);
	}

	/**************************************************************************
	
	>	void Log::SetSeverity(uint Severity)
	
		Author:		Tim Browse
		Date:		15/4/2002
		Inputs:		Severity - the new severity threshold to use.
	
		Purpose:	Change the current severity threshold of the Log.

					Only messages with a severity the same or lower than the
					new severity value will be logged (because lower
					severity codes indicate more severity, 0 being
					the most).

					Less severe messages will be ignored.
	
	**************************************************************************/
	
	void Log::SetSeverity(uint Severity)
	{
		m_Severity = Severity;
	}

};

