//
// LogFile.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "LogFile.h"

#include "Errors.h"

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vos
{
	/**************************************************************************
	
	>	LogFile::LogFile()
	
		Author:		Tim Browse
		Date:		15/4/2002
	
		Purpose:	Constructor - do not use this form, as it is protected.
	
	**************************************************************************/
	
	LogFile::LogFile() : m_pLogFile(NULL)
	{
	}

	/**************************************************************************
	
	>	LogFile::LogFile(File* pLogFile)
	
		Author:		Tim Browse
		Date:		15/4/2002
		Inputs:		pLogFile - the file to log messages to.
	
		Purpose:	Constructor - make a LogFile object that logs its messages
					to the File object specified.
	
	**************************************************************************/
	
	LogFile::LogFile(File* pLogFile) : m_pLogFile(pLogFile)
	{
	}

	/**************************************************************************
	
	>	LogFile::~LogFile()
	
		Author:		Tim Browse
		Date:		15/4/2002
	
		Purpose:	Destructor
	
	**************************************************************************/
	
	LogFile::~LogFile()
	{
		// NB. This is not supposed to close the logfile object, so it doesn't.
		//     We assume the object does not belong to us.
	}

	/**************************************************************************
	
	>	void LogFile::LogMsg(const char *szMsg, int Severity, uint32 Flags)
	
		Author:		Tim Browse
		Date:		15/4/2002
		Inputs:		Msg - the message to log
					Severity - the severity of the message (0 is most
							   severe).  You can ignore severity if you 
							   want, and can just use 0 all the time.
					Flags - any flags associated with the message.  The
							LogFile class places no meaning on these
							flags - but derived classes may use them.
	
		Purpose:	Standard message logging function from the Log interface.
	
	**************************************************************************/
	
	void LogFile::LogMsg(const char *szMsg, int Severity, uint32 Flags)
	{
		if (m_pLogFile == NULL)
		{
			// No log file; complain and exit
			COMPLAIN("LogFile::LogMsg() - no active log file object!");
			return;
		}

		// If this message is severe enough for this log file, then 
		// write it out.
		if (Severity <= m_Severity)
		{
			m_pLogFile->WriteLine(szMsg);
		}
	}
};

