//
// MemoryFile.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_MemoryFile_h
#define vos_MemoryFile_h

#include "vos.h"

#include "File.h"

namespace vos
{
	/**************************************************************************

	>	class MemoryFile : public File

		Author:		Tim Browse
		Date:		29/11/99

		Purpose:	Concrete File class for dealing with RAM-based files.

	**************************************************************************/

	class MemoryFile : public File
	{
		public:
			// Constructors/Destructor
			MemoryFile();
			~MemoryFile();

			// Creating MemoryFiles
			Error Create(byte* pBuffer, uint cbBufferLength);
			Error Create(File *pSourceFile);

			// Opening and closing files
			Error Open(byte* pBuffer, uint cbBufferLength, FileMode Mode = fam_Full);
			Error Open(File *pSourceFile, FileMode Mode = fam_Full);

			virtual Error Open(FileMode Mode = fam_Full);
			virtual void Close();

			virtual bool IsOpen() const;

			// Determine the size of the file, in bytes
			Error GetSize(uint* pSize);

			// Binary read/write
			// NB. does no endian conversions
			Error Read(void* pData, uint cBytes, uint* pcBytes = NULL);
			Error Write(const void* pData, uint cBytes, uint* pcBytes = NULL);

			// Seeking
			Error SeekFromStart(uint Offset);
			Error SeekFromEnd(uint Offset);
			Error SeekRelative(int Offset);

			// Get file read/write pointer position
			Error GetPos(uint* pPos) const;

			// Test for end of file.
			bool eof() const;

			Error ReadLine(String* pData);

		protected:
			bool IsLineTerminator(byte ch);

			// Destroy/forget our memory buffer
			void DeleteBuffer(void);

		private:
			// The RAM-based data for this file (NULL for files that are not open)
			byte *m_pData;

			// Number of bytes in this RAM-based file.
			uint m_cbBufferLength;

			// Current read/write position in the file.
			uint m_Pos;

			// Determine if we are responsible for deleting m_pData on exit
			bool m_IOwnTheBuffer;
			bool m_FileOpen;
	};
};

#endif // !vos_MemoryFile_h
