//
// PreferencesImp.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_PreferencesImp_h
#define vos_PreferencesImp_h

#include "vos.h"


namespace vos
{
	class String;
	class Preferences;

	/**************************************************************************
	
	>	class PreferencesImp
	
		Author:		Tim Browse
		Date:		15/4/2002
	
		Purpose:	Provide an interface for the Bridge pattern used for
					Preferences.  Concrete derivations of this class/interface
					will provide platform-specific code for storing/reading
					preferences.

					You will not need to use this unless porting vOS to a new
					platform.
	
	**************************************************************************/
	
	class PreferencesImp
	{
		public:
			PreferencesImp();
			virtual ~PreferencesImp();

			void LinkToPreferences(Preferences* pPrefs);

		public:
			// Read/write of preferences
			virtual bool Read(const String& PrefName, String*	pPrefValue) = 0;
			virtual bool Read(const String& PrefName, int*		pPrefValue) = 0;
			virtual bool Read(const String& PrefName, bool*		pPrefValue) = 0;
			virtual bool Read(const String& PrefName, FileSpec* pPrefValue) = 0;

			virtual bool Write(const String& PrefName, const String& PrefValue) = 0;
			virtual bool Write(const String& PrefName, int PrefValue) = 0;
			virtual bool Write(const String& PrefName, bool PrefValue) = 0;
			virtual bool Write(const String& PrefName, const FileSpec& PrefValue) = 0;

			// Deleting preferences
			virtual void DeleteAll() = 0;

		protected:
			// Implementation

			// Link to vos object
			Preferences* m_pPrefs;

		private:
			// Prohibit copying
			PreferencesImp(const PreferencesImp& rhs);
			PreferencesImp& operator=(const PreferencesImp& rhs);
	};
};

#endif // !vos_Preferences_h
