//
// ResourceID.cpp
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "ResourceID.h"

#include "Application.h"

#ifdef VOS_MSWINDOWS
#include "Win32\Win32_Headers.h"
#endif

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vos
{
	ResourceID::ResourceID(int ResType, int ID) 
	{ 
		m_Type = ResType; 

		m_ID = MAKEINTRESOURCE(ID); 
	}

	String StringResourceID::Load() const
	{
		String Result;
		Load(&Result);
		return Result;
	}

	void StringResourceID::Printf(String* pString, ...)
	{
		// Process varargs list
		va_list ArgList;
		va_start(ArgList, pString);

		// Create & load a string for this format ID
		String FormatString = Load();

		// Fill in caller's string according to this new string
		pString->Printf_va(FormatString.c_str(), ArgList);

		// All done
		va_end(ArgList);
	}

#if defined VOS_MSWINDOWS

	bool StringResourceID::Load(String* pString) const
	{
		// This copes with strings up to 512 chars long.
		const int kStringLength = 512;
		TCHAR szString[kStringLength];

		UINT nID = (UINT) GetID();

		// Fail if it's a null ID.
		if (nID == 0)
			return false;

		int nCharsCopied = ::LoadString((HINSTANCE) Application::GetInstance(),
										nID, 
										szString, 
										kStringLength - 1);

		// Copy result
		if (nCharsCopied > 0)
		{
			pString->assign(szString);
		}

		// Tell caller if the string was loaded.
		return (nCharsCopied > 0);
	}

#elif defined VOS_MACOS

	bool StringResourceID::Load(String* pString) const
	{
		// Use Pascal Strings (256 chars max). Will this clash with the PC version?
		::StringHandle hPString = ::GetString(GetID());
		if(::ResError() || ::MemError() || (hPString == NULL))
		{
			return false;
		}
		else
		{
			// We own this string, so we can lock, unlock & dispose of it without
			// maintaining its existing state.
			// Lots of casting due to using a StringHandle with Handle routines
			::HLock( (::Handle)hPString );
			// The pointer in the Handle is the Str255.
			// How does this next line work? 
			// The first char in the handle is the length, so **hPString is the 
			// length as an unsigend char which we cast to int.
			// The second char is the start of the string, so &(**hPString)+1 is the 
			// address of the string data, which we can optimize to (*hPString + 1)
			// and must then cast to char* to make sure assign()'s signature is correct.
			pString->assign(((char*)*hPString) + 1, (int)**hPString);
			::HUnlock((::Handle)hPString );
			::ReleaseResource((::Handle)hPString);
		}
		
		// Tell caller the string was loaded.
		return true;
	}

#endif

};
