//
// TimeOfDay.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_TimeOfDay_h
#define vos_TimeOfDay_h

#include "vos.h"

// Lose annoying Win32 macro
#undef GetCurrentTime

namespace vos
{
	/**************************************************************************
	
	>	class TimeOfDay
	
		Author:		Tim Browse
		Date:		18/4/2002
	
		Purpose:	Hold the time of day (as hours, minutes and seconds).
	
	**************************************************************************/
	
	class TimeOfDay
	{
		public:
			TimeOfDay();
			TimeOfDay(uint8 Hours, uint8 Minutes, uint8 Seconds = 0);

		public:
			bool Set(uint8 Hours, uint8 Minutes, uint8 Seconds = 0);

			// Access functions
			uint8 GetHours()   const { return m_Hours;   }
			uint8 GetMinutes() const { return m_Minutes; }
			uint8 GetSeconds() const { return m_Seconds; }

			// Arithmetic
			void AddHours(int nHours);
			void AddMinutes(int nMinutes);
			void AddSeconds(int nSeconds);

			// Comparison
			bool operator==(const TimeOfDay& rhs) const;
			bool operator!=(const TimeOfDay& rhs) const;
			bool operator<(const TimeOfDay& rhs) const;
			bool operator<=(const TimeOfDay& rhs) const;
			bool operator>=(const TimeOfDay& rhs) const;
			bool operator>(const TimeOfDay& rhs) const;

			static TimeOfDay GetCurrentTime();

		private:
			uint32 MakeTimeValue() const;
			bool IsValid() const;

		private:
			uint8 m_Hours;
			uint8 m_Minutes;
			uint8 m_Seconds;
	};
};

#endif // !vos_TimeOfDay_h
