//
// Trace.cpp - OS independent debug tracing routines
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#include "StdHdr.h"

#include "Trace.h"

#include "vOS.h"

#include "String.h"

// Set up definitions so we can use minimal Win32 includes

#define WIN32_LEAN_AND_MEAN		// Exclude rarely-used stuff from Windows headers

#ifndef _X86_
#define _X86_
#endif

// Win32 headers

//
// This is the order <windows.h> does things - unnecessary headers
// commented out.  Uncomment them if problems occur compiling
// cross-platform vGui headers on Win32.
//
// Do NOT uncomment them to get Win32 cpp files to compile - add the
// headers to those cpp files instead.
//

//#include <excpt.h>
#include <stdarg.h>


//
// Set WINVER to 4.0 because we use minimal includes and WINVER will
// get defined to 0x500 by windef.h, and this feature is in beta atm.
//

#ifndef WINVER
#define WINVER 0x0400
#endif

#if defined VOS_MSWINDOWS
#include "Win32\Win32_Headers.h"
#endif

//
// Enable memory tracking
//
#ifdef _DEBUG
#define new vosDEBUG_NEW
#endif

namespace vos
{
	void Trace(const char* szMsg, ...)
	{
		va_list arglist;
		va_start(arglist, szMsg);

		String DebugOutput;
		DebugOutput.Printf_va(szMsg, arglist);

		// Send to debug stream
#ifdef VOS_MSWINDOWS
		::OutputDebugString(DebugOutput.c_str());
#elif (defined VOS_MACOS)
		Str255 PStr;
		::DebugStr(DebugOutput.p_str(PStr));
#endif

		va_end(arglist);
	}
};
