//
// Trace.h - OS independent debug tracing routines
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos_Trace_h
#define vos_Trace_h

/*!
	\file

	Provide platform-independent tracing routines - i.e. text based
	debug stream.

	It's easiest to use the TRACE macro, which can take a printf format
	string and variable arguments, or just a static string.

	For example:

	\code

		TRACE("Current value is %d\n", m_Value);

	\endcode

*/

namespace vos
{
	void Trace(const char* szMsg, ...);
};

/*!
	Macro: TRACE(szFormat, ...)

	Use this macro to trace debug output to a standard place (which
	depends on the platform, and the vOS implementation of vos::Trace()).

	\code

		TRACE("Get ready...\n");
		TRACE("Current value is %d\n", m_Value);

	\endcode

	You should add a line ending "\n" to strings when you want a
	new line to start at the end.
*/

#ifdef _DEBUG
#define TRACE vos::Trace
#else
#define TRACE 1 ? 0 : vos::Trace
#endif

#endif // !vos_Trace_h
