//
// TreeNode.h
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef vos__TreeNode_h
#define vos__TreeNode_h

#include "vos.h"

namespace vos
{

	typedef enum
	{
		TC_Undefined,
		TC_InsertBefore,
		TC_InsertAfter,
		TC_InsertAsFirstChild,
		TC_InsertAsLastChild
	}
	TTreeContext;

	/**************************************************************************
	
	>	class TreeNode
	
		Author:		Tim Browse
		Date:		18/4/2002
	
		Purpose:	Provide a simple doubly linked tree structure.  Can
					be used for many things.  Does not use templates, so
					requires appropriate cast operators when used.
	
	**************************************************************************/
	
	class TreeNode
	{
		public:
			// construction and initialisation
			TreeNode();
			virtual ~TreeNode();

			// navigation functions
			TreeNode* GetNext() const;
			TreeNode* GetPrevious() const;
			TreeNode* GetLastSibling();
			TreeNode* GetFirstChild() const;
			TreeNode* GetLastChild() const;
			TreeNode* GetParent() const;

			// Insertion Features
			virtual TreeNode* InsertAfter(TreeNode* pContext);
			virtual TreeNode* InsertBefore(TreeNode* pContext);
			virtual TreeNode* InsertLast(TreeNode* pContext);
			virtual TreeNode* InsertFirstChild(TreeNode* pContext);
			virtual TreeNode* InsertLastChild(TreeNode* pContext);

			// Generic insert
			virtual TreeNode* InsertAt(TreeNode* pContext, TTreeContext Context);

			// Deleting and Removing Features
			virtual TreeNode* RemoveSubTree();
			virtual void DeleteSubTree();

			// A function to replace this item in the tree with another item
			virtual TreeNode* ReplaceWith(TreeNode* pReplacementObject);

			// Searching functions
			TreeNode*	FindRoot();
			TreeNode*	FindNextDepthFirst(TreeNode* pRootItem);
			TreeNode*	FindNextDepthFirstReverse(TreeNode* pRootItem);

			bool GetRightmostChild(TreeNode*& pRightmostChild);

			bool IsDescendedFrom(TreeNode *pAncestor);

			// Debugging Aids
			void DumpTree(int Nesting=0);
			
		private:
			// pointers to the nodes that surround this one
			TreeNode* m_pParent;
			TreeNode* m_pNext;
			TreeNode* m_pPrevious;
			TreeNode* m_pFirstChild;
	};

};

#endif // !vos__TreeNode_h
