//
// Win32Registry.h - functions for dealing with the registry.
//

//
// This software is protected by the GNU Lesser General Public License,
// also known as the 'GNU library License', or the LGPL.
//
// See the file COPYING.txt for details.
//

#ifndef Win32Registry_h
#define Win32Registry_h

#include <windows.h>

namespace vos
{
	class String;

	/**************************************************************************
	
	>	class Win32Registry
	
		Author:		Tim Browse
		Date:		18/4/2002
	
		Purpose:	Provide a set of functions for convenient access to the
					Windows registry.
	
	**************************************************************************/
	
	class Win32Registry
	{
		public:
			// Useful function for use by Win32 vOS-based programs that want 
			// to read string values from the registry (copes with any length
			// of string value).
			static bool ReadStringValue(HKEY hKey, 
										const String& ValueName,
										String* pValue);

			// Find out if the specified key/value exists in the registry.
			// NB. a key can have a key and value with the same name as children,
			//     which is why there are two functions.
			static bool KeyExists(HKEY hParent, const String& KeyName);
			static bool ValueExists(HKEY hParent, const String& ValueName);

			//
			// Making registry entries
			//

			// Remember to call CloseKey when you are finished with the key.
			static HKEY CreateKey(HKEY hParent, const String& KeyName);

			static bool CreateStringValue(HKEY hParent, 
										  const String& Name,
										  const String& Value);

			static bool SetStringValue(HKEY hParent, 
									   const String& Name,
									   const String& Value);

			//
			// Using registry entries
			//
			static HKEY OpenKey(HKEY hParent, const String& KeyName);
			static void CloseKey(HKEY hKey);

			//
			// Deleting registry entries
			//

			// Delete a key and all its descendants
			static bool DeleteKey(HKEY hKey, const String& SubKeyName);

			// Delete a key, but it must be empty (i.e. hav eno children)
			static bool DeleteEmptyKey(HKEY hKey, const String& SubKeyName);

			// Delete a value
			static bool DeleteValue(HKEY hKey, const String& ValueName);

			//
			// String manipulation
			//

			static bool SplitRegistryString(const String& RegistryKey,
											HKEY* phKey, String* pKeyName);

			static void SplitRegistryName(const String& ValueName, 
										  String* pParentKey, 
										  String* pLeafName);

			static bool KeyHasChildren(HKEY hKey, const String& SubKeyName);
			static bool KeyHasChildren(HKEY hKey);

	};
};

#endif // !Win32Registry_h
